@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -148,8 +148,8 @@
         ],
 
         'description' => [
-            follow_keys_from => 'this hash will contain the same keys as the hash pointed by the path string',
-            allow_keys_from => 'this hash will allow keys from the keys of the hash pointed by the path string',
+            follow_keys_from => 'this hash contains the same keys as the hash pointed by the path string',
+            allow_keys_from => 'this hash allows keys from the keys of the hash pointed by the path string',
             ordered => 'keep track of the order of the elements of this hash',
             default_keys => 'default keys hashes.',
             auto_create_keys => 'always create a set of keys specified in this list',
@@ -157,7 +157,7 @@
             allow_keys => 'specify a set of allowed keys',
             allow_keys_matching => 'Keys must match the specified regular expression.',
             default_with_init => 'specify a set of keys to create and initialization on some elements . E.g. \' foo => "X=Av Y=Bv", bar => "Y=Av Z=Cz"\' ',
-            help => 'Specify help string specific to possible values. E.g for "light" value, you could write " red => \'stop\', green => \'walk\' ',
+            help => 'Specify help string applicable to values. The keys are regexp matched to the beggining of the value. See C<help> parameter of L<Config::Model::Value/DESCRIPTION> for more possibilities',
             replace => 'Used for enum to substitute one value with another. This parameter must be used to enable user to upgrade a configuration with obsolete values. The old value is the key of the hash, the new one is the value of the hash',
             warn_if_key_match => 'Warn user if a key is created matching this regular expression',
             warn_unless_key_match => 'Warn user if a key is created not matching this regular expression',
